@@ -7,7 +7,6 @@
 //! Add keys to your app’s Information Property List that declare your app’s data
 //! management capabilities.
 
-use crate::serialize_enum_option;
 use serde::{Deserialize, Serialize};
 
 /// Documents
@@ -25,6 +24,7 @@ pub struct Documents {
     /// * Core Foundation
     #[serde(
         rename = "CFBundleDocumentTypes",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_document_types: Option<Vec<BundleDocumentTypes>>,
@@ -37,6 +37,7 @@ pub struct Documents {
     /// * Core Services
     #[serde(
         rename = "UISupportsDocumentBrowser",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub supports_document_browser: Option<bool>,
@@ -50,6 +51,7 @@ pub struct Documents {
     /// * Core Services
     #[serde(
         rename = "LSSupportsOpeningDocumentsInPlace",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub supports_opening_documents_in_place: Option<bool>,
@@ -63,7 +65,7 @@ pub struct Documents {
     #[serde(
         rename = "NSPersistentStoreTypeKey",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub persistent_store_type_key: Option<PersistentStoreTypeKey>,
     /// A Boolean value that indicates whether the system should download documents before
@@ -79,6 +81,7 @@ pub struct Documents {
     /// * AppKit
     #[serde(
         rename = "NSDownloadsUbiquitousContents",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub downloads_ubiquitous_contents: Option<bool>,
@@ -109,7 +112,11 @@ pub struct UrlSchemes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "CFBundleURLTypes", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CFBundleURLTypes",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bundle_url_types: Option<Vec<BundleUrlTypes>>,
 }
 
@@ -128,6 +135,7 @@ pub struct BundleDocumentTypes {
     /// * Core Foundation
     #[serde(
         rename = "CFBundleTypeIconFile",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_type_icon_file: Option<String>,
@@ -156,7 +164,7 @@ pub struct BundleDocumentTypes {
     #[serde(
         rename = "CFBundleTypeRole",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub bundle_type_role: Option<BundleTypeRole>,
     /// The ranking of this app among apps that declare themselves as editors or viewers
@@ -173,7 +181,7 @@ pub struct BundleDocumentTypes {
     #[serde(
         rename = "LSHandlerRank",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub handler_rank: Option<HandlerRank>,
     /// The document file types the app supports.
@@ -186,7 +194,11 @@ pub struct BundleDocumentTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "LSItemContentTypes", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "LSItemContentTypes",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub item_content_types: Option<Vec<String>>,
     /// A Boolean value indicating whether the document is distributed as a bundle.
     ///
@@ -198,7 +210,11 @@ pub struct BundleDocumentTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "LSTypeIsPackage", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "LSTypeIsPackage",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_is_package: Option<bool>,
     /// The subclass used to create instances of this document.
     ///
@@ -210,7 +226,11 @@ pub struct BundleDocumentTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "NSDocumentClass", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSDocumentClass",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub document_class: Option<String>,
     /// The file types that this document can be exported to.
     ///
@@ -222,7 +242,11 @@ pub struct BundleDocumentTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "NSExportableTypes", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSExportableTypes",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub exportable_types: Option<Vec<String>>,
 }
 
@@ -267,7 +291,11 @@ pub struct BundleUrlTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "CFBundleTypeRole", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CFBundleTypeRole",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bundle_type_role: Option<BundleTypeRole>,
     /// The name of the icon image file, without the extension, to be used for this type.
     ///
@@ -281,6 +309,7 @@ pub struct BundleUrlTypes {
     /// * Core Foundation
     #[serde(
         rename = "CFBundleURLIconFile",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_url_icon_file: Option<String>,
@@ -306,7 +335,11 @@ pub struct BundleUrlTypes {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(rename = "CFBundleURLSchemes", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CFBundleURLSchemes",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bundle_url_schemes: Option<Vec<String>>,
 }
 
@@ -323,6 +356,7 @@ pub struct UniversalTypeIdentifiers {
     /// * Core Services
     #[serde(
         rename = "UTExportedTypeDeclarations",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub exported_type_declarations: Option<Vec<ExportedTypeDeclarations>>,
@@ -336,6 +370,7 @@ pub struct UniversalTypeIdentifiers {
     /// * Core Services
     #[serde(
         rename = "UTImportedTypeDeclarations",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub imported_type_declarations: Option<Vec<ImportedTypeDeclarations>>,
@@ -362,7 +397,11 @@ pub struct ExportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeDescription", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeDescription",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_description: Option<String>,
     /// The bundle icon resource to associate with this type.
     ///
@@ -372,7 +411,11 @@ pub struct ExportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeIconFile", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeIconFile",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_icon_file: Option<String>,
     /// One or more bundle icon resources to associate with this type.
     ///
@@ -382,7 +425,11 @@ pub struct ExportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeIconFiles", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeIconFiles",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_icon_files: Option<Vec<String>>,
     /// The Uniform Type Identifier to assign to this type.
     ///
@@ -402,7 +449,11 @@ pub struct ExportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeReferenceURL", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeReferenceURL",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_reference_url: Option<String>,
     /// A dictionary defining one or more equivalent type identifiers.
     ///
@@ -437,7 +488,11 @@ pub struct ImportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeDescription", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeDescription",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_description: Option<String>,
     /// The bundle icon resource to associate with this type.
     ///
@@ -447,7 +502,11 @@ pub struct ImportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeIconFile", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeIconFile",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_icon_file: Option<String>,
     /// One or more bundle icon resources to associate with this type.
     ///
@@ -457,7 +516,11 @@ pub struct ImportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeIconFiles", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeIconFiles",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_icon_files: Option<Vec<String>>,
     /// The Uniform Type Identifier to assign to this type.
     ///
@@ -477,7 +540,11 @@ pub struct ImportedTypeDeclarations {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(rename = "UTTypeReferenceURL", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "UTTypeReferenceURL",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub type_reference_url: Option<String>,
     /// A dictionary defining one or more equivalent type identifiers.
     ///
@@ -521,6 +588,7 @@ pub struct Network {
     /// * UIKit
     #[serde(
         rename = "NSAdvertisingAttributionReportEndpoint",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub advertising_attribution_report_endpoint: Option<String>,
@@ -584,6 +652,7 @@ pub struct Network {
     /// * Security
     #[serde(
         rename = "NSAppTransportSecurity",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub app_transport_security: Option<AppTransportSecurity>,
@@ -602,7 +671,11 @@ pub struct Network {
     ///
     /// ## Framework
     /// * Network
-    #[serde(rename = "NSBonjourServices", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSBonjourServices",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub bonjour_services: Option<Vec<String>>,
     /// A Boolean value that indicates your app supports CloudKit Sharing.
     ///
@@ -631,7 +704,11 @@ pub struct Network {
     ///
     /// ## Framework
     /// * CloudKit
-    #[serde(rename = "CKSharingSupported", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "CKSharingSupported",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub sharing_supported: Option<bool>,
 }
 
@@ -679,6 +756,7 @@ pub struct AppTransportSecurity {
     /// * Security
     #[serde(
         rename = "NSAllowsArbitraryLoads",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub allows_arbitrary_loads: Option<bool>,
@@ -711,6 +789,7 @@ pub struct AppTransportSecurity {
     /// * Security
     #[serde(
         rename = "NSAllowsArbitraryLoadsForMedia",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub allows_arbitrary_loads_for_media: Option<bool>,
@@ -745,6 +824,7 @@ pub struct AppTransportSecurity {
     /// * Security
     #[serde(
         rename = "NSAllowsArbitraryLoadsInWebContent",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub allows_arbitrary_loads_in_web_content: Option<bool>,
@@ -783,6 +863,7 @@ pub struct AppTransportSecurity {
     /// * Security
     #[serde(
         rename = "NSAllowsLocalNetworking",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub allows_local_networking: Option<bool>,
@@ -830,7 +911,11 @@ pub struct AppTransportSecurity {
     ///
     /// ## Framework
     /// * Security
-    #[serde(rename = "NSExceptionDomains", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSExceptionDomains",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub exception_domains: Option<ExceptionDomains>,
     /// A collection of certificates that App Transport Security expects when connecting
     /// to named domains.
@@ -872,7 +957,11 @@ pub struct AppTransportSecurity {
     ///
     /// ## Framework
     /// * Security
-    #[serde(rename = "NSPinnedDomains", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSPinnedDomains",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub pinned_domains: Option<PinnedDomains>,
 }
 
@@ -905,6 +994,7 @@ pub struct ExceptionDomains {
     /// * Security
     #[serde(
         rename = "NSIncludesSubdomains",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub includes_subdomains: Option<bool>,
@@ -937,6 +1027,7 @@ pub struct ExceptionDomains {
     /// * Security
     #[serde(
         rename = "NSExceptionAllowsInsecureHTTPLoads",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub exception_allows_insecure_http_loads: Option<bool>,
@@ -958,7 +1049,7 @@ pub struct ExceptionDomains {
     #[serde(
         rename = "NSExceptionMinimumTLSVersion",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub exception_minimum_tls_version: Option<ExceptionMinimumTlsVersion>,
     /// A Boolean value indicating whether to override the perfect forward secrecy
@@ -982,6 +1073,7 @@ pub struct ExceptionDomains {
     /// * Security
     #[serde(
         rename = "NSExceptionRequiresForwardSecrecy",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub exception_requires_forward_secrecy: Option<bool>,
@@ -1008,6 +1100,7 @@ pub struct ExceptionDomains {
     /// * Security
     #[serde(
         rename = "NSRequiresCertificateTransparency",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub requires_certificate_transparency: Option<bool>,
@@ -1060,6 +1153,7 @@ pub struct PinnedDomains {
     /// * Security
     #[serde(
         rename = "NSIncludesSubdomains",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub includes_subdomains: Option<bool>,
@@ -1095,6 +1189,7 @@ pub struct PinnedDomains {
     /// * Security
     #[serde(
         rename = "NSPinnedCAIdentities",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub pinned_ca_identities: Option<Vec<Spkisha256Base64>>,
@@ -1124,7 +1219,11 @@ pub struct Spkisha256Base64 {
     ///
     /// ## Framework
     /// * Security
-    #[serde(rename = "SPKI-SHA256-BASE64", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "SPKI-SHA256-BASE64",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub spki_sha256_base64: Option<String>,
 }
 
@@ -1138,7 +1237,11 @@ pub struct Storage {
     ///
     /// ## Framework
     /// * AppKit
-    #[serde(rename = "APFiles", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "APFiles",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub files: Option<Files>,
     /// The base path to the files or directories the app installs.
     ///
@@ -1147,7 +1250,11 @@ pub struct Storage {
     ///
     /// ## Framework
     /// * AppKit
-    #[serde(rename = "APInstallerURL", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "APInstallerURL",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub installer_url: Option<String>,
     /// A Boolean value indicating whether the app continues working if the system purges
     /// the local storage.
@@ -1159,6 +1266,7 @@ pub struct Storage {
     /// * Foundation
     #[serde(
         rename = "NSSupportsPurgeableLocalStorage",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub supports_purgeable_local_storage: Option<bool>,
@@ -1172,6 +1280,7 @@ pub struct Storage {
     /// * Core Services
     #[serde(
         rename = "LSFileQuarantineEnabled",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub file_quarantine_enabled: Option<bool>,
@@ -1186,6 +1295,7 @@ pub struct Storage {
     /// * UIKit
     #[serde(
         rename = "UIFileSharingEnabled",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub file_sharing_enabled: Option<bool>,
@@ -1199,6 +1309,7 @@ pub struct Storage {
     /// * Core Foundation
     #[serde(
         rename = "CSResourcesFileMapped",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub resources_file_mapped: Option<bool>,
@@ -1216,6 +1327,7 @@ pub struct Storage {
     /// * AppKit
     #[serde(
         rename = "NSDownloadsUbiquitousContents",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub downloads_ubiquitous_contents: Option<bool>,
@@ -1234,6 +1346,7 @@ pub struct Files {
     /// * AppKit
     #[serde(
         rename = "APDisplayedAsContainer",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub displayed_as_container: Option<bool>,
@@ -1283,7 +1396,7 @@ pub struct Files {
     #[serde(
         rename = "APInstallAction",
         skip_serializing_if = "Option::is_none",
-        serialize_with = "serialize_enum_option"
+        serialize_with = "crate::serialize_enum_option"
     )]
     pub install_action: Option<InstallAction>,
 }
@@ -1313,6 +1426,7 @@ pub struct CoreMlModels {
     /// * Core Services
     #[serde(
         rename = "LSBundleContainsCoreMLmlmodelc",
+        serialize_with = "crate::serialize_option",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_contains_core_ml_mlmodelc: Option<bool>,
@@ -1328,6 +1442,10 @@ pub struct Java {
     ///
     /// ## Framework
     /// * Foundation
-    #[serde(rename = "NSJavaRoot", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "NSJavaRoot",
+        serialize_with = "crate::serialize_option",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub java_root: Option<String>,
 }
